@@ -440,7 +440,7 @@ class C_PORTCOUNTS:
     
     .. note::
     
-        CFP modules return the number 8 which is the maximum number of 10G ports, but the actual number of ports can be configured dynamically using the :class:`~xoa_driver.internals.core.commands.m_commands.M_CFPCONFIG` command.
+        CFP modules return the number 8 which is the maximum number of 10G ports, but the actual number of ports can be configured dynamically using the M_CFPCONFIG` command.
 
     """
 
@@ -1189,11 +1189,11 @@ class C_TKLICFILE:
 
     @dataclass(frozen=True)
     class SetDataAttr:
-        license_content: XmpField[XmpByteList] = XmpField(XmpByteList)  # ToDo: probably wrong type
+        license_content: XmpField[XmpByteList] = XmpField(XmpByteList)  #TODO: probably wrong type
 
     @dataclass(frozen=True)
     class GetDataAttr:
-        license_content: XmpField[XmpByteList] = XmpField(XmpByteList)  # ToDo: probably wrong type
+        license_content: XmpField[XmpByteList] = XmpField(XmpByteList)  #TODO: probably wrong type
 
     def get(self) -> "Token[GetDataAttr]":
         """Get Xena TimeKeeper license file content. 
