@@ -626,8 +626,10 @@ class AlignLockStatus(IntEnum):
     """Alignment Lock Off"""
     ALIGNON = 1
     """Alignment Lock On"""
-    ALIGNUNSTABLE = 3
-    """Alignment Lock Unstable"""
+    ALIGNOFFUNSTABLE = 2
+    """Alignment Lock Off and Unstable"""
+    ALIGNONUNSTABLE = 3
+    """Alignment Lock On but Unstable"""
 
 
 class PRBSLockStatus(IntEnum):
@@ -1685,10 +1687,9 @@ class ShadowWorkingSelection(IntEnum):
     WORKING = 1
     """Working"""
 
-
 class FilterType(IntEnum):
     """Filter Type for Impairemennt"""
-    SHADOWN = 0 
+    SHADOW = 0 
     """Shadow Copy"""
     WORKING = 1
     """Wokring Copy"""
@@ -1792,4 +1793,26 @@ class TSNStatisticsTypes(IntEnum):
     PDELAY = 3
     """PDelay."""
     SYNCRATE = 4
-    """Sync rate."""
\ No newline at end of file
+    """Sync rate."""
+
+
+class PPMSweepMode(IntEnum):
+    """Module clock PPM Sweep Modes"""
+    OFF = 0
+    """Off"""
+    TRIANGLE = 1
+    """Triangle sweeping"""
+
+class PPMSweepStatus(IntEnum):
+    """Module clock PPM Sweep Status"""
+    OFF = 0
+    """Off"""
+    SWEEPING = 1
+    """The module is sweeping"""
+
+class ReconciliationSublayerSupport (IntEnum):
+    """Reconciliation Sublayer Support"""
+    NO_SUPPORT = 0
+    """Not Supported"""
+    FAULT_SIGNALING = 1
+    """Supported, which means P_FAULTSTATUS and P_FAULTSIGNALLING are supported by the port."""
\ No newline at end of file
