@@ -51,30 +51,6 @@ class PP_ALARMS_ERRORS:
         return Token(self._connection, build_get_request(self, module=self._module, port=self._port))
 
 
-@register_command
-@dataclass
-class PP_ALARMS_ERRORS_CLEAR:
-    """
-    Clear all PCS/PMA alarms.
-    """
-
-    code: typing.ClassVar[int] = 273
-    pushed: typing.ClassVar[bool] = False
-
-    _connection: "interfaces.IConnection"
-    _module: int
-    _port: int
-
-    @dataclass(frozen=True)
-    class SetDataAttr:
-        pass
-
-    def set(self, dummy: int) -> "Token":
-        """Clear all PCS/PMA alarms.
-        """
-        return Token(self._connection, build_set_request(self, module=self._module, port=self._port))
-
-
 @register_command
 @dataclass
 class PP_TXLANECONFIG:
@@ -515,7 +491,7 @@ class PP_PMAERRPUL_PARAMS:
         :param coeff: (0.01 < coeff < 9.99) * 100
         :type coeff: int
         :param exp: -3 < exp < -17
-        :type exp: Infinite
+        :type exp: int
         """
         return Token(self._connection, build_set_request(self, module=self._module, port=self._port, duration=duration, period=period, repetition=repetition, coeff=coeff, exp=exp))
 
@@ -806,12 +782,12 @@ class PP_EYEMEASURE:
     @dataclass(frozen=True)
     class SetDataAttr:
         status: XmpField[XmpByte] = XmpField(XmpByte, choices=StartOrStop)  # coded byte, status of the serdes.
-        dummy: XmpField[XmpByteList] = XmpField(XmpByteList)  # list of bytes, reserved for future expansion.
+        dummy: XmpField[XmpByteList] = XmpField(XmpByteList)  # list of bytes, should always be 0, reserved for future expansion.
 
     @dataclass(frozen=True)
     class GetDataAttr:
         status: XmpField[XmpByte] = XmpField(XmpByte, choices=SerdesStatus)  # coded byte, status of the serdes.
-        dummy: XmpField[XmpByteList] = XmpField(XmpByteList)  # list of bytes, reserved for future expansion.
+        dummy: XmpField[XmpByteList] = XmpField(XmpByteList)  # list of bytes, should always be 0, reserved for future expansion.
 
     def get(self) -> "Token[GetDataAttr]":
         """Get the status of the BER eye-measure data gathering process.
@@ -821,15 +797,13 @@ class PP_EYEMEASURE:
         """
         return Token(self._connection, build_get_request(self, module=self._module, port=self._port, indices=[self._serdes_xindex]))
 
-    def set(self, status: StartOrStop, dummy: typing.List[int]) -> "Token":
+    def set(self, status: StartOrStop) -> "Token":
         """Start/stop a new BER eye-measure on a 25G serdes.
 
         :param status: status of the serdes
         :type status: StartOrStop
-        :param dummy: reserved for future expansion
-        :type dummy: int
         """
-        return Token(self._connection, build_set_request(self, module=self._module, port=self._port, indices=[self._serdes_xindex], status=status, dummy=dummy))
+        return Token(self._connection, build_set_request(self, module=self._module, port=self._port, indices=[self._serdes_xindex], status=status, dummy=[0]))
 
     set_stop = functools.partialmethod(set, StartOrStop.STOP)
     """Start a new BER eye-measure on a 25G serdes.
