@@ -17,15 +17,15 @@ class GConfigHistogram:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.time = P4G_TIME_HIST_CONF(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TIME_HIST_CONF`
+        Representation of P4G_TIME_HIST_CONF
         """
         self.payload = P4G_PAYLOAD_HIST_CONF(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_PAYLOAD_HIST_CONF`
+        Representation of P4G_PAYLOAD_HIST_CONF
         """
         self.transaction = P4G_TRANSACTION_HIST_CONF(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TRANSACTION_HIST_CONF`
+        Representation of P4G_TRANSACTION_HIST_CONF
         """
 
 
@@ -34,15 +34,15 @@ class GRecalculatesHistogram:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.time = P4G_RECALC_TIME_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RECALC_TIME_HIST`
+        Representation of P4G_RECALC_TIME_HIST
         """
         self.payload = P4G_RECALC_PAYLOAD_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RECALC_PAYLOAD_HIST`
+        Representation of P4G_RECALC_PAYLOAD_HIST
         """
         self.transaction = P4G_RECALC_TRANSACTION_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RECALC_TRANSACTION_HIST`
+        Representation of P4G_RECALC_TRANSACTION_HIST
         """
 
 
@@ -51,7 +51,7 @@ class GHistogram:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.transaction = P4G_APP_TRANSACTION_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_APP_TRANSACTION_HIST`
+        Representation of P4G_APP_TRANSACTION_HIST
         """
         self.recalculates = GRecalculatesHistogram(conn, module_id, port_id, group_idx)
         """L47 Histogram Recalculation."""
