@@ -18,11 +18,11 @@ class GMacL2:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.client = P4G_L2_CLIENT_MAC(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_L2_CLIENT_MAC`
+        Representation of P4G_L2_CLIENT_MAC
         """
         self.server = P4G_L2_SERVER_MAC(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_L2_SERVER_MAC`
+        Representation of P4G_L2_SERVER_MAC
         """
 
 class GGatewayL2:
@@ -30,15 +30,15 @@ class GGatewayL2:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.use = P4G_L2_USE_GW(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_L2_USE_GW`
+        Representation of P4G_L2_USE_GW
         """
         self.ipv4 = P4G_L2_GW(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_L2_GW`
+        Representation of P4G_L2_GW
         """
         self.ipv6 = P4G_L2_IPV6_GW(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_L2_IPV6_GW`
+        Representation of P4G_L2_IPV6_GW
         """
     
 
@@ -47,11 +47,11 @@ class GVlanL2:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.enable = P4G_VLAN_ENABLE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_VLAN_ENABLE`
+        Representation of P4G_VLAN_ENABLE
         """
         self.tci = P4G_VLAN_TCI(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_VLAN_TCI`
+        Representation of P4G_VLAN_TCI
         """
 
 
@@ -60,7 +60,7 @@ class GL2:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.address_resolve = P4G_L2_USE_ADDRESS_RES(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_L2_USE_ADDRESS_RES`
+        Representation of P4G_L2_USE_ADDRESS_RES
         """
         self.mac = GMacL2(conn, module_id, port_id, group_idx)
         """L2 MAC"""
