@@ -22,11 +22,11 @@ class GIPv4L3:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.client_range = P4G_CLIENT_RANGE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_CLIENT_RANGE`
+        Representation P4G_CLIENT_RANGE
         """
         self.server_range = P4G_SERVER_RANGE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_SERVER_RANGE`
+        Representation P4G_SERVER_RANGE
         """
 
 
@@ -35,19 +35,19 @@ class GIPv6L3:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.client_range = P4G_IPV6_CLIENT_RANGE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IPV6_CLIENT_RANGE`
+        Representation P4G_IPV6_CLIENT_RANGE
         """
         self.server_range = P4G_IPV6_SERVER_RANGE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IPV6_SERVER_RANGE`
+        Representation P4G_IPV6_SERVER_RANGE
         """
         self.traffic_class = P4G_IPV6_TRAFFIC_CLASS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IPV6_TRAFFIC_CLASS`
+        Representation P4G_IPV6_TRAFFIC_CLASS
         """
         self.flow_label = P4G_IPV6_FLOW_LABEL(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IPV6_FLOW_LABEL`
+        Representation P4G_IPV6_FLOW_LABEL
         """
 
 
@@ -56,23 +56,23 @@ class GDifferentialServiceL3:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.type = P4G_IP_DS_TYPE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IP_DS_TYPE`
+        Representation P4G_IP_DS_TYPE
         """
         self.value = P4G_IP_DS_VALUE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IP_DS_VALUE`
+        Representation P4G_IP_DS_VALUE
         """
         self.mask = P4G_IP_DS_MASK(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IP_DS_MASK`
+        Representation P4G_IP_DS_MASK
         """
         self.range_limits = P4G_IP_DS_MINMAX(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IP_DS_MINMAX`
+        Representation P4G_IP_DS_MINMAX
         """
         self.step = P4G_IP_DS_STEP(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IP_DS_STEP`
+        Representation P4G_IP_DS_STEP
         """
 
 
@@ -81,7 +81,7 @@ class GL3:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.ip_version = P4G_IP_VERSION(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_IP_VERSION`
+        Representation P4G_IP_VERSION
         """
         self.ipv4 = GIPv4L3(conn, module_id, port_id, group_idx)
         """L3 IPv4 Configurations"""
@@ -89,7 +89,7 @@ class GL3:
         """L3 IPv6 Configurations"""
         self.diffserv = GDifferentialServiceL3(conn, module_id, port_id, group_idx)
         """L3 IPv6 DS Configurations"""
-        self.nat = P4G_NAT(conn, module_id, port_id, group_idx) # TODO: maybe to add extra logic for this command based on the description
+        self.nat = P4G_NAT(conn, module_id, port_id, group_idx) #TODO: maybe to add extra logic for this command based on the description
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_NAT`
+        Representation P4G_NAT
         """
\ No newline at end of file
