@@ -29,23 +29,23 @@ class GPayloadRaw:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.type = P4G_RAW_PAYLOAD_TYPE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_PAYLOAD_TYPE`
+        Representation of P4G_RAW_PAYLOAD_TYPE
         """
         self.total_length = P4G_RAW_PAYLOAD_TOTAL_LEN(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_PAYLOAD_TOTAL_LEN`
+        Representation of P4G_RAW_PAYLOAD_TOTAL_LEN
         """
         self.rx_length = P4G_RAW_RX_PAYLOAD_LEN(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_RX_PAYLOAD_LEN`
+        Representation of P4G_RAW_RX_PAYLOAD_LEN
         """
         self.content = P4G_RAW_PAYLOAD(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_PAYLOAD`
+        Representation of P4G_RAW_PAYLOAD
         """
         self.repeat_length = P4G_RAW_PAYLOAD_REPEAT_LEN(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_PAYLOAD_REPEAT_LEN`
+        Representation of P4G_RAW_PAYLOAD_REPEAT_LEN
         """
 
 
@@ -54,19 +54,19 @@ class GConnectionRaw:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.incarnation = P4G_RAW_CONN_INCARNATION(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_CONN_INCARNATION`
+        Representation of P4G_RAW_CONN_INCARNATION
         """
         self.repetitions = P4G_RAW_CONN_REPETITIONS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_CONN_REPETITIONS`
+        Representation of P4G_RAW_CONN_REPETITIONS
         """
         self.lifetime = P4G_RAW_CONN_LIFETIME(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_CONN_LIFETIME`
+        Representation of P4G_RAW_CONN_LIFETIME
         """
         self.close_condition = P4G_RAW_CLOSE_CONN(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_CLOSE_CONN`
+        Representation of P4G_RAW_CLOSE_CONN
         """
 
 
@@ -75,11 +75,11 @@ class GBurstyRaw:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.transmission = P4G_RAW_BURSTY_TX(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_BURSTY_TX`
+        Representation of P4G_RAW_BURSTY_TX
         """
         self.config = P4G_RAW_BURSTY_CONF(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_BURSTY_CONF`
+        Representation of P4G_RAW_BURSTY_CONF
         """
 
 
@@ -88,11 +88,11 @@ class GTransmitRaw:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.during_ramp = P4G_RAW_TX_DURING_RAMP(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_TX_DURING_RAMP`
+        Representation of P4G_RAW_TX_DURING_RAMP
         """
         self.time_offset = P4G_RAW_TX_TIME_OFFSET(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_TX_TIME_OFFSET`
+        Representation of P4G_RAW_TX_TIME_OFFSET
         """
 
 class GDownloadRequestRaw:
@@ -100,15 +100,15 @@ class GDownloadRequestRaw:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.server_must_wait = P4G_RAW_HAS_DOWNLOAD_REQ(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_HAS_DOWNLOAD_REQ`
+        Representation of P4G_RAW_HAS_DOWNLOAD_REQ
         """
         self.transactions_number = P4G_RAW_REQUEST_REPEAT(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_REQUEST_REPEAT`
+        Representation of P4G_RAW_REQUEST_REPEAT
         """
         self.content = P4G_RAW_DOWNLOAD_REQUEST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_DOWNLOAD_REQUEST`
+        Representation of P4G_RAW_DOWNLOAD_REQUEST
         """
 
 
@@ -117,7 +117,7 @@ class GCountersTransaction:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.transaction = P4G_APP_TRANSACTION_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_APP_TRANSACTION_COUNTERS`
+        Representation of P4G_APP_TRANSACTION_COUNTERS
         """
 
 
@@ -126,11 +126,11 @@ class GRaw:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.test_scenario = P4G_RAW_TEST_SCENARIO(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_TEST_SCENARIO`
+        Representation of P4G_RAW_TEST_SCENARIO
         """
         self.utilization = P4G_RAW_UTILIZATION(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_RAW_UTILIZATION`
+        Representation of P4G_RAW_UTILIZATION
         """
         
         self.download_request = GDownloadRequestRaw(conn, module_id, port_id, group_idx)
