@@ -9,8 +9,8 @@ from xoa_driver.internals.core.commands import (
     P4G_REPLAY_USER_INCARNATION,
     P4G_REPLAY_USER_REPETITIONS,
     P4G_APP_REPLAY_COUNTERS,
-    # P4G_REPLAY_SCHEDULING, # TODO: need to implment
-    # P4G_REPLAY_SYNCHRONIZATION, # TODO: need to implment
+    # P4G_REPLAY_SCHEDULING, #TODO: need to implement
+    # P4G_REPLAY_SYNCHRONIZATION, #TODO: need to implement
 )
 
 class GFilesReplay:
@@ -22,12 +22,12 @@ class GFilesReplay:
         self.__group_idx = group_idx
         self.indices = P4G_REPLAY_FILE_INDICES(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_REPLAY_FILE_INDICES`
+        Representation of P4G_REPLAY_FILE_INDICES
         """
 
-    def name(self, replay_file_idx: int) -> "P4G_REPLAY_FILE_NAME": # TODO: Not sure about function name
+    def name(self, replay_file_idx: int) -> "P4G_REPLAY_FILE_NAME": #TODO: Not sure about function name
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_REPLAY_FILE_NAME`
+        Representation of P4G_REPLAY_FILE_NAME
         """
         return P4G_REPLAY_FILE_NAME(
             self.__conn, 
@@ -39,7 +39,7 @@ class GFilesReplay:
 
     async def clear_index(self, replay_file_idx: int) -> None:
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_REPLAY_FILE_CLEAR`
+        Representation of P4G_REPLAY_FILE_CLEAR
         """
         await P4G_REPLAY_FILE_CLEAR(
             self.__conn, 
@@ -53,11 +53,11 @@ class GUserReplay:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.incarnation = P4G_REPLAY_USER_INCARNATION(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_REPLAY_USER_INCARNATION`
+        Representation of P4G_REPLAY_USER_INCARNATION
         """
         self.repetitions = P4G_REPLAY_USER_REPETITIONS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_REPLAY_USER_REPETITIONS`
+        Representation of P4G_REPLAY_USER_REPETITIONS
         """
 
 
@@ -66,7 +66,7 @@ class GCounters:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.replay = P4G_APP_REPLAY_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_APP_REPLAY_COUNTERS`
+        Representation of P4G_APP_REPLAY_COUNTERS
         """
 
 
@@ -75,7 +75,7 @@ class GReplay:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.utilization = P4G_REPLAY_UTILIZATION(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_REPLAY_UTILIZATION`
+        Representation of P4G_REPLAY_UTILIZATION
         """
         # self.scheduling = P4G_REPLAY_SCHEDULING(conn, module_id, port_id, group_idx)
         # self.synchronization = P4G_REPLAY_SYNCHRONIZATION(conn, module_id, port_id, group_idx)
