@@ -41,15 +41,15 @@ class GAckTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.duplicate_tresholds = P4G_TCP_DUP_THRES(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_DUP_THRES`
+        Representation of P4G_TCP_DUP_THRES
         """
-        self.frequency = P4G_TCP_ACK_FREQUENCY(conn, module_id, port_id, group_idx) # TODO: probably need a better name to be closer to cmd description
+        self.frequency = P4G_TCP_ACK_FREQUENCY(conn, module_id, port_id, group_idx) #TODO: probably need a better name to be closer to cmd description
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_ACK_FREQUENCY`
+        Representation of P4G_TCP_ACK_FREQUENCY
         """
         self.timeout = P4G_TCP_ACK_TIMEOUT(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_ACK_TIMEOUT`
+        Representation of P4G_TCP_ACK_TIMEOUT
         """
 
 class GRetransmitionTimeoutTcp:
@@ -57,19 +57,19 @@ class GRetransmitionTimeoutTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.syn_value = P4G_TCP_SYN_RTO(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_SYN_RTO`
+        Representation of P4G_TCP_SYN_RTO
         """
         self.value = P4G_TCP_RTO(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RTO`
+        Representation of P4G_TCP_RTO
         """
         self.range_limits = P4G_TCP_RTO_MINMAX(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RTO_MINMAX`
+        Representation of P4G_TCP_RTO_MINMAX
         """
         self.prolonged_mode = P4G_TCP_RTO_PROLONGED_MODE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RTO_PROLONGED_MODE`
+        Representation of P4G_TCP_RTO_PROLONGED_MODE
         """
 
 class GStateCountersTcp:
@@ -77,15 +77,15 @@ class GStateCountersTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.current = P4G_TCP_STATE_CURRENT(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_STATE_CURRENT`
+        Representation of P4G_TCP_STATE_CURRENT
         """
         self.total = P4G_TCP_STATE_TOTAL(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_STATE_TOTAL`
+        Representation of P4G_TCP_STATE_TOTAL
         """
         self.rate = P4G_TCP_STATE_RATE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_STATE_RATE`
+        Representation of P4G_TCP_STATE_RATE
         """
 
 
@@ -94,15 +94,15 @@ class GMaxSegmentSize:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.type = P4G_TCP_MSS_TYPE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_MSS_TYPE`
+        Representation of P4G_TCP_MSS_TYPE
         """
         self.range_limits = P4G_TCP_MSS_MINMAX(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_MSS_MINMAX`
+        Representation of P4G_TCP_MSS_MINMAX
         """
         self.fixed_value = P4G_TCP_MSS_VALUE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_MSS_VALUE`
+        Representation of P4G_TCP_MSS_VALUE
         """
 
 
@@ -111,11 +111,11 @@ class GPacketCountersTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.rx = P4G_TCP_RX_PACKET_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RX_PACKET_COUNTERS`
+        Representation of P4G_TCP_RX_PACKET_COUNTERS
         """
         self.tx = P4G_TCP_TX_PACKET_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_TX_PACKET_COUNTERS`
+        Representation of P4G_TCP_TX_PACKET_COUNTERS
         """
 
 
@@ -124,11 +124,11 @@ class GPayloadCountersTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.rx = P4G_TCP_RX_PAYLOAD_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RX_PAYLOAD_COUNTERS`
+        Representation of P4G_TCP_RX_PAYLOAD_COUNTERS
         """
         self.tx = P4G_TCP_TX_PAYLOAD_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_TX_PAYLOAD_COUNTERS`
+        Representation of P4G_TCP_TX_PAYLOAD_COUNTERS
         """
 
 
@@ -137,11 +137,11 @@ class GCountersTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.retransmission = P4G_TCP_RETRANSMIT_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RETRANSMIT_COUNTERS`
+        Representation of P4G_TCP_RETRANSMIT_COUNTERS
         """
         self.error = P4G_TCP_ERROR_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_ERROR_COUNTERS`
+        Representation of P4G_TCP_ERROR_COUNTERS
         """
         self.packet = GPacketCountersTcp(conn, module_id, port_id, group_idx)
         """Packet counters"""
@@ -156,11 +156,11 @@ class GRxHistogramTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.total_bytes = P4G_TCP_RX_TOTAL_BYTES_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RX_TOTAL_BYTES_HIST`
+        Representation of P4G_TCP_RX_TOTAL_BYTES_HIST
         """
         self.good_bytes = P4G_TCP_RX_GOOD_BYTES_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RX_GOOD_BYTES_HIST`
+        Representation of P4G_TCP_RX_GOOD_BYTES_HIST
         """
 
 
@@ -169,11 +169,11 @@ class GTxHistogramTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.total_bytes = P4G_TCP_TX_TOTAL_BYTES_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_TX_TOTAL_BYTES_HIST`
+        Representation of P4G_TCP_TX_TOTAL_BYTES_HIST
         """
         self.good_bytes = P4G_TCP_TX_GOOD_BYTES_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_TX_GOOD_BYTES_HIST`
+        Representation of P4G_TCP_TX_GOOD_BYTES_HIST
         """
 
 
@@ -182,11 +182,11 @@ class GConnHistogramTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.establish_times = P4G_TCP_ESTABLISH_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_ESTABLISH_HIST`
+        Representation of P4G_TCP_ESTABLISH_HIST
         """
         self.close_times = P4G_TCP_CLOSE_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_CLOSE_HIST`
+        Representation of P4G_TCP_CLOSE_HIST
         """
 
 
@@ -206,11 +206,11 @@ class GReceiverWindowTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.size = P4G_TCP_WINDOW_SIZE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_WINDOW_SIZE`
+        Representation of P4G_TCP_WINDOW_SIZE
         """
         self.scaling = P4G_TCP_WINDOW_SCALING(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_WINDOW_SCALING`
+        Representation of P4G_TCP_WINDOW_SCALING
         """
 
 
@@ -219,11 +219,11 @@ class GCongestionWindowTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.congestion_mode = P4G_TCP_CONGESTION_MODE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_CONGESTION_MODE`
+        Representation of P4G_TCP_CONGESTION_MODE
         """
         self.icwnd_calc_method = P4G_TCP_ICWND_CALC_METHOD(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_ICWND_CALC_METHOD`
+        Representation of P4G_TCP_ICWND_CALC_METHOD
         """
         
 
@@ -232,15 +232,15 @@ class GTcp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.clear_post_test_statistics = P4G_CLEAR_POST_STAT(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_CLEAR_POST_STAT`
+        Representation of P4G_CLEAR_POST_STAT
         """
         self.rtt_value = P4G_TCP_RTT_VALUE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_RTT_VALUE`
+        Representation of P4G_TCP_RTT_VALUE
         """
         self.iss_treshold = P4G_TCP_ISSTHRESH(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_TCP_ISSTHRESH`
+        Representation of P4G_TCP_ISSTHRESH
         """
         self.mss = GMaxSegmentSize(conn, module_id, port_id, group_idx)
         """Max segment size config"""
