@@ -21,11 +21,11 @@ class GHistogramUdp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.rx_bytes = P4G_UDP_RX_BYTES_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_RX_BYTES_HIST`
+        Representation of P4G_UDP_RX_BYTES_HIST
         """
         self.tx_bytes = P4G_UDP_TX_BYTES_HIST(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_TX_BYTES_HIST`
+        Representation of P4G_UDP_TX_BYTES_HIST
         """
 
 
@@ -34,11 +34,11 @@ class GPayloadCountersUdp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.rx = P4G_UDP_RX_PAYLOAD_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_RX_PAYLOAD_COUNTERS`
+        Representation of P4G_UDP_RX_PAYLOAD_COUNTERS
         """
         self.tx = P4G_UDP_TX_PAYLOAD_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_TX_PAYLOAD_COUNTERS`
+        Representation of P4G_UDP_TX_PAYLOAD_COUNTERS
         """
 
 
@@ -47,11 +47,11 @@ class GPacketCountersUdp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.rx = P4G_UDP_RX_PACKET_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_RX_PACKET_COUNTERS`
+        Representation of P4G_UDP_RX_PACKET_COUNTERS
         """
         self.tx = P4G_UDP_TX_PACKET_COUNTERS(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_TX_PACKET_COUNTERS`
+        Representation of P4G_UDP_TX_PACKET_COUNTERS
         """
 
 
@@ -71,15 +71,15 @@ class GPacketSizeUdp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.type = P4G_UDP_PACKET_SIZE_TYPE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_PACKET_SIZE_TYPE`
+        Representation of P4G_UDP_PACKET_SIZE_TYPE
         """
         self.range_limits = P4G_UDP_PACKET_SIZE_MINMAX(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_PACKET_SIZE_MINMAX`
+        Representation of P4G_UDP_PACKET_SIZE_MINMAX
         """
         self.value = P4G_UDP_PACKET_SIZE_VALUE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_PACKET_SIZE_VALUE`
+        Representation of P4G_UDP_PACKET_SIZE_VALUE
         """
 
 
@@ -88,15 +88,15 @@ class GStateCountersUdp:
     def __init__(self, conn: "itf.IConnection", module_id: int, port_id: int, group_idx: int) -> None:
         self.current = P4G_UDP_STATE_CURRENT(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_STATE_CURRENT`
+        Representation of P4G_UDP_STATE_CURRENT
         """
         self.total = P4G_UDP_STATE_TOTAL(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_STATE_TOTAL`
+        Representation of P4G_UDP_STATE_TOTAL
         """
         self.rate = P4G_UDP_STATE_RATE(conn, module_id, port_id, group_idx)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.p4g_commands.P4G_UDP_STATE_RATE`
+        Representation of P4G_UDP_STATE_RATE
         """
 
 
