@@ -1,6 +1,6 @@
 from xoa_driver import modules
 
-# region Vlkyrie Modules
+# region Valkyrie Modules
 
 valkyrie_modules = {
     # family_d
@@ -46,24 +46,38 @@ valkyrie_modules = {
     # family_l
     "Thor-400G-7S-1P[b]": modules.MThor400G7S1P_b,
     "Thor-400G-7S-1P[c]": modules.MThor400G7S1P_c,
-    # "Freya-800G-1S-1P[a]": modules.MFreya800G1S1P_a,
-    # "Freya-800G-1S-1P-OSFP[a]": modules.MFreya800G1S1POSFP_a,
-    # "Freya-800G-4S-1P": modules.MFreya800G4S1P,
-    # "Freya-800G-4S-1P-OSFP": modules.MFreya800G4S1POSFP,
+    "Freya-800G-1S-1P[a]": modules.MFreya800G1S1P_a,
+    "Freya-800G-1S-1P[b]": modules.MFreya800G1S1P_b,
+    "Freya-800G-1S-1P-OSFP[a]": modules.MFreya800G1S1POSFP_a,
+    "Freya-800G-4S-1[a]": modules.MFreya800G4S1P_a,
+    "Freya-800G-4S-1P-OSFP[a]": modules.MFreya800G4S1POSFP_a,
     
     # family_m
     "Odin-1G-3S-6P-T1-RJ45": modules.MOdin1G3S6PT1RJ45,
     
     # family_n
     "Odin-40G-2S-2P": modules.MOdin40G2S2P,
+    
+    # family_combi
+    "Odin-10G-4S-2P-Combi": modules.MOdin10G4S2PCombi,
+    "Odin-10G-4S-2P-Combi[b]": modules.MOdin10G4S2PCombi_b,
+    
 }
 
 # endregion
 
+# region Chimera Modules
+
 chimera_modules = {
     "Chimera-100G-5S-2P": modules.ModuleChimera,
 }
 
+# endregion
+
+# region Vulcan Modules
+
 vulcan_modules = {
     "Xena L47 Module": modules.ModuleL47,
 }
+
+# endregion
