@@ -48,7 +48,7 @@ class TesterSession:
                 raise WrongTesterPasswordError(self.pwd) from None
             raise e
         if self.keepalive:
-            asyncio.create_task(self.__do_keepalive(), name="keepalive") # TODO: need to handle this task on interuption
+            asyncio.create_task(self.__do_keepalive(), name="keepalive") #TODO: need to handle this task on interruption
         return self
 
     async def __do_keepalive(self) -> None:
@@ -61,12 +61,14 @@ class TesterSession:
         """
         Check if connection is still active.
         """
+
         return self._conn.is_connected
 
     async def logoff(self) -> None:
         """
-        Gracefull logoff from the tester.
+        Gracefully log off from the tester.
         """
+
         await C_LOGOFF(self._conn).set()
         self._conn.close()
 
@@ -74,6 +76,7 @@ class TesterSession:
         """
         Return information about all active sessions on the tester.
         """
+
         sessions = await C_INDICES(self._conn).get()
         session_ids = sessions.session_ids
         query_sessions = [
