@@ -8,16 +8,19 @@ from xoa_driver.internals.core.commands import (
 
 class UploadFile:
     """File uploading functions of the Valkyrie tester."""
+
     def __init__(self, conn: "itf.IConnection") -> None:
         self.start = C_FILESTART(conn)
         """Start uploading file.
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_FILESTART`
+        Representation of C_FILESTART
         """
+
         self.data = C_FILEDATA(conn)
         """Uploading a file fragment.
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_FILEDATA`
+        Representation of C_FILEDATA
         """
+        
         self.finish = C_FILEFINISH(conn)
         """Finish uploading file.
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_FILEFINISH`
+        Representation of C_FILEFINISH
         """
\ No newline at end of file
