@@ -9,24 +9,28 @@ class ManagementInterface:
     """
     Tester management interface address configuration.
     """
+
     def __init__(self, conn: "itf.IConnection" ) -> None:
         self.ip_address = C_IPADDRESS(conn)
         """
         Chassis management port IP address configuration.
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_IPADDRESS`
+        Representation of C_IPADDRESS
         """
+
         self.dhcp = C_DHCP(conn)
         """
         Chassis management port IP address configuration with DHCP.
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_DHCP`
+        Representation of C_DHCP
         """
+
         self.macaddress = C_MACADDRESS(conn)
         """
         Chassis management port MAC address.
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_MACADDRESS`
+        Representation of C_MACADDRESS
         """
+        
         self.hostname = C_HOSTNAME(conn)
         """
         Chassis management hostname.
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_HOSTNAME`
+        Representation of C_HOSTNAME
         """
\ No newline at end of file
