@@ -12,14 +12,15 @@ class L47VeTester(L47Tester):
     """
     Representation of a virtual Xena Vulcan Tester.
     """
+    
     def __init__(self, host: str, username: str, password: str = "xena", port: int = 22606, *, debug: bool = False ) -> None:
         super().__init__(host=host, username=username, password=password, port=port, debug=debug)
         self.version_no_minor = C_VERSIONNO_MINOR(self._conn)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_VERSIONNO_MINOR`
+        Representation of C_VERSIONNO_MINOR
         """
 
         self.build_string = C_BUILDSTRING(self._conn)
         """
-        Representation of :class:`~xoa_driver.internals.core.commands.c_commands.C_BUILDSTRING`
+        Representation of C_BUILDSTRING
         """
