@@ -10,13 +10,16 @@ from .internals.core.commands.subtypes import (
 
 # indices types
 from .internals.indices.connection_group.cg import ConnectionGroupIdx as ConnectionGroup
-from .internals.indices.filter.base_filter import BaseFilterIdx as BaseFilter
-from .internals.indices.filter.genuine_filter import GenuineFilterIdx as GenuineFilter
+from .internals.indices.filter.base_filter import BaseFilterIdx as BasePortFilter
+from .internals.indices.filter.genuine_filter import GenuineFilterIdx as GenuinePortFilter
 from .internals.indices.length_term import LengthTermIdx as LengthTerm
 from .internals.indices.match_term import MatchTermIdx as MatchTerm
 from .internals.indices.port_dataset import PortDatasetIdx as PortDataset
 from .internals.indices.streams.base_stream import BaseStreamIdx as BaseStream
 from .internals.indices.streams.genuine_stream import GenuineStreamIdx as GenuineStream
+from .internals.ports.port_l23.chimera.port_emulation import CFlow as ImpairmentFlow
+from .internals.ports.port_l23.chimera.filter_definition.general import ModeBasic as BasicImpairmentFlowFilter
+from .internals.ports.port_l23.chimera.filter_definition.general import ModeExtended as ExtendedImpairmentFlowFilter
 
 
 __all__ = (
@@ -25,11 +28,14 @@ __all__ = (
     "NdpChunk",
     "PortSpeedChuck",
     "ConnectionGroup",
-    "BaseFilter",
-    "GenuineFilter",
+    "BasePortFilter",
+    "GenuinePortFilter",
     "LengthTerm",
     "MatchTerm",
     "PortDataset",
     "BaseStream",
     "GenuineStream",
+    "ImpairmentFlow",
+    "BasicImpairmentFlowFilter",
+    "ExtendedImpairmentFlowFilter",
 )
\ No newline at end of file
