@@ -1,4 +1,4 @@
-#: All avaliable test module types.
+#: All available test module types.
 
 from .internals.modules.modules_l23.module_l23_base import ModuleL23
 from .internals.modules.modules_l23.family_d import (
@@ -36,13 +36,19 @@ from .internals.modules.modules_l23.family_k import MThor400G7S1P
 from .internals.modules.modules_l23.family_l import (
     MThor400G7S1P_b,
     MThor400G7S1P_c,
-    # MFreya800G1S1P_a,
-    # MFreya800G1S1POSFP_a,
-    # MFreya800G4S1P,
-    # MFreya800G4S1POSFP,
+    MFreya800G1S1P_a,
+    MFreya800G1S1P_b,
+    MFreya800G1S1POSFP_a,
+    MFreya800G4S1P_a,
+    MFreya800G4S1POSFP_a,
 )
 from .internals.modules.modules_l23.family_m import MOdin1G3S6PT1RJ45
 from .internals.modules.modules_l23.family_n import MOdin40G2S2P
+from .internals.modules.modules_l23.family_combi import (
+    MOdin10G4S2PCombi,
+    MOdin10G4S2PCombi_b,
+)
+
 
 from .internals.modules.module_l23ve import ModuleL23VE
 from .internals.modules.module_chimera import ModuleChimera
@@ -79,11 +85,14 @@ GenericL23Module = typing.Union[
         "MThor400G7S1P",
         "MThor400G7S1P_b",
         "MThor400G7S1P_c",
-        # "MFreya800G1S1P_a",
-        # "MFreya800G1S1POSFP_a",
-        # "MFreya800G4S1P",
-        # "MFreya800G4S1POSFP",
+        "MFreya800G1S1P_a",
+        "MFreya800G1S1P_b",
+        "MFreya800G1S1POSFP_a",
+        "MFreya800G4S1P_a",
+        "MFreya800G4S1POSFP_a",
         "MOdin1G3S6PT1RJ45",
+        "MOdin10G4S2PCombi",
+        "MOdin10G4S2PCombi_b",
     ]
 
 GenericAnyModule = typing.Union[
@@ -123,11 +132,14 @@ __all__ = (
     "MThor400G7S1P",
     "MThor400G7S1P_b",
     "MThor400G7S1P_c",
-    # "MFreya800G1S1P_a",
-    # "MFreya800G1S1POSFP_a",
-    # "MFreya800G4S1P",
-    # "MFreya800G4S1POSFP",
+    "MFreya800G1S1P_a",
+    "MFreya800G1S1P_b",
+    "MFreya800G1S1POSFP_a",
+    "MFreya800G4S1P_a",
+    "MFreya800G4S1POSFP_a",
     "MOdin1G3S6PT1RJ45",
+    "MOdin10G4S2PCombi",
+    "MOdin10G4S2PCombi_b",
     "ModuleL23VE",
     "ModuleChimera",
     "ModuleL47",
