@@ -1,7 +1,7 @@
-#: All avaliable tester types.
+#: All available tester types.
 
 from .internals.testers.l23_tester import L23Tester
-# from .internals.testers.l23ve_tester import L23VeTester
+from .internals.testers.l23ve_tester import L23VeTester
 from .internals.testers.l47_tester import L47Tester
 from .internals.testers.l47ve_tester import L47VeTester
 
@@ -9,7 +9,7 @@ import typing
 
 GenericAnyTester = typing.Union[
     "L23Tester",
-    # "L23VeTester",
+    "L23VeTester",
     "L47Tester",
     "L47VeTester",
 ]
@@ -17,7 +17,7 @@ GenericAnyTester = typing.Union[
 
 __all__ = (
     "L23Tester",
-    # "L23VeTester",
+    "L23VeTester",
     "L47Tester",
     "L47VeTester",
     "GenericAnyTester",
